@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Window::Tk;
-$App::ClusterSSH::Window::Tk::VERSION = '4.15';
+
 # ABSTRACT: Object for creating windows using Tk
 
 use English qw( -no_match_vars );
@@ -10,7 +10,7 @@ use English qw( -no_match_vars );
 use base qw/ App::ClusterSSH::Base /;
 use vars qw/ %keysymtocode %keycodetosym /;
 
-use Net::Domain qw(hostfqdn);
+use Sys::Hostname qw/ hostname /;
 use File::Temp qw/:POSIX/;
 use Fcntl;
 use POSIX ":sys_wait_h";
@@ -348,8 +348,7 @@ sub add_host_by_name() {
     if ( $menus{host_entry} ) {
         $self->debug( 2, "host=", $menus{host_entry} );
         my @names
-            = $self->parent->resolve_names(
-            split( /\s+/, $menus{host_entry} ) );
+            = $self->parent->resolve_names( split( /\s+/, $menus{host_entry} ) );
         $self->debug( 0, 'Opening to: ', join( ' ', @names ) ) if (@names);
         $self->open_client_windows(@names);
     }
@@ -357,7 +356,7 @@ sub add_host_by_name() {
     if ( defined $menus{listbox} && $menus{listbox}->curselection() ) {
         my @hosts = $menus{listbox}->get( $menus{listbox}->curselection() );
         $self->debug( 2, "host=", join( ' ', @hosts ) );
-        $self->open_client_windows( $self->resolve_names(@hosts) );
+        $self->open_client_windows( $self->parent->resolve_names(@hosts) );
     }
 
     $self->build_hosts_menu();
@@ -602,7 +601,7 @@ sub substitute_macros {
     }
     {
         my $macro_hostname = $self->config->{macro_hostname};
-        my $hostname       = hostfqdn();
+        my $hostname       = $self->config->{hostname_override} || hostname();
         $text =~ s!$macro_hostname!$hostname!xsmg;
         $ENV{CSSH_HOSTNAME} = $hostname;
     }
@@ -628,48 +627,46 @@ sub substitute_macros {
     $ENV{CSSH_CONNECTION_PORT}   = $servers{$svr}{port};
 
     # Set up environment variables in the macro environment
-    for my $i (qw/ 1 2 3 4 /) {
-        my $macro_user_command = 'macro_user_' . $i . '_command';
-        my $macro_user         = $self->config->{ 'macro_user_' . $i };
+    for my $i (qw/ 1 2 3 4 / ) {
+        my $macro_user_command = 'macro_user_'.$i.'_command';
+        my $macro_user = $self->config->{'macro_user_'.$i};
 
         next unless $text =~ $macro_user;
-        if ( !$self->config->{$macro_user_command} ) {
+        if( ! $self->config->{ $macro_user_command } ) {
             $text =~ s/$macro_user//xsmg;
             next;
         }
 
-        my $cmd = $self->config->{$macro_user_command};
+        my $cmd = $self->config->{ $macro_user_command };
 
         local $SIG{CHLD} = undef;
 
         my $stderr_fh = gensym;
         my $stdout_fh = gensym;
-        my $child_pid = eval { open3( undef, $stdout_fh, $stderr_fh, $cmd ) };
+        my $child_pid = eval { open3(undef, $stdout_fh, $stderr_fh, $cmd) };
 
-        if ( my $err = $@ ) {
-
-   # error message is hardcoded into open3 - tidy it up a little for our users
-            $err =~ s/ at .*//;
-            $err =~ s/open3: //;
+        if (my $err=$@) {
+            # error message is hardcoded into open3 - tidy it up a little for our users
+            $err=~ s/ at .*//;
+            $err=~ s/open3: //;
             $err =~ s/( failed)/' $1/;
             $err =~ s/(exec of) /$1 '/;
             warn "Macro failure for '$macro_user_command': $err";
             next;
         }
-        waitpid( $child_pid, 0 );
+        waitpid($child_pid, 0);
         my $cmd_rc = $? >> 8;
 
         my @stdout = <$stdout_fh>;
         my @stderr = <$stderr_fh>;
 
-        if ( $cmd_rc > 0 || @stderr ) {
-            warn "Macro failure for '$macro_user_command'", $/;
+        if ( $cmd_rc > 0 || @stderr ){
+            warn "Macro failure for '$macro_user_command'",$/;
             warn "Exited with error output:: @stderr" if @stderr;
             warn "Exited with non-zero return code: $cmd_rc", $/ if $cmd_rc;
-        }
-        else {
+        } else {
             #$self->send_text_to_all_servers( $stdout );
-            return join( '', @stdout );
+            return join('', @stdout);
         }
     }
 
@@ -1207,7 +1204,7 @@ sub setup_repeat() {
 
                         for ($cmd) {
                             if (m/^open$/) {
-                                my @new_hosts = $self->resolve_names(@tags);
+                                my @new_hosts = $self->parent->resolve_names(@tags);
                                 $self->open_client_windows(@new_hosts);
                                 $self->build_hosts_menu();
                                 last;
@@ -1279,10 +1276,16 @@ sub setup_repeat() {
 
 sub create_windows() {
     my ($self) = @_;
+    my ($screen_height) = $xdisplay->{height_in_pixels};
+    my ($screen_width) = $xdisplay->{width_in_pixels};
     $self->debug( 2, "create_windows: started" );
 
     $windows{main_window}
         = MainWindow->new( -title => "ClusterSSH", -class => 'cssh', );
+    if ($screen_height * $screen_width >= 8294400) # display 4k or bigger
+    {
+        $windows{main_window}->optionAdd('*font', 'Nimbus 14'); # better for 4k displays
+    }
     $windows{main_window}->withdraw;    # leave withdrawn until needed
 
     if ( defined( $self->config->{console_position} )
